@@ -31,21 +31,20 @@ the same expressions are False:
 
 This module is designed to be imported together with ``unicode_literals`` on
 Python 2 to bring the meaning of ``str`` back into alignment with unprefixed
-string literals (i.e. ``unicode``).
+string literals (i.e. ``unicode`` subclasses).
 
 Note that ``str()`` (and ``print()``) would then normally call the
 ``__unicode__`` method on objects in Python 2. To define string
-representations of your objects portably across Py3 and Py2, see the
-python_2_unicode_compatible decorator in :mod:`future.utils`.
+representations of your objects portably across Py3 and Py2, use the
+:func:`python_2_unicode_compatible` decorator in  :mod:`future.utils`.
     
 """
 
 from collections import Iterable
 
 from numbers import Number
-from future.utils import PY3, istext
+from future.utils import PY3, istext, with_metaclass, isnewbytes
 from future.builtins.backports import no, issubset
-from future.builtins.backports.newbytes import newbytes
 
 
 if PY3:
@@ -53,7 +52,12 @@ if PY3:
     unicode = str
 
 
-class newstr(unicode):
+class BaseNewStr(type):
+    def __instancecheck__(cls, instance):
+        return isinstance(instance, unicode)
+
+
+class newstr(with_metaclass(BaseNewStr, unicode)):
     """
     A backport of the Python 3 str object to Py2
     """
@@ -78,15 +82,19 @@ class newstr(unicode):
         
         if len(args) == 0:
             return super(newstr, cls).__new__(cls)
-        elif isinstance(args[0], newstr):
+        # Was: elif isinstance(args[0], newstr):
+        # We use type() instead of the above because we're redefining
+        # this to be True for all unicode string subclasses. Warning:
+        # This may render newstr un-subclassable.
+        elif type(args[0]) == newstr:
             return args[0]
         elif isinstance(args[0], unicode):
             value = args[0]
-        elif isinstance(args[0], bytes):
-            if 'encoding' not in kwargs:
-                value = args[0].__str__()
+        elif isinstance(args[0], bytes):   # i.e. Py2 bytes or newbytes
+            if 'encoding' in kwargs or len(args) > 1:
+                value = args[0].decode(*args[1:], **kwargs)
             else:
-                value = args[0].encode(**kwargs)
+                value = args[0].__str__()
         else:
             value = args[0]
         return super(newstr, cls).__new__(cls, value)
@@ -104,26 +112,27 @@ class newstr(unicode):
 
     def __contains__(self, key):
         errmsg = "'in <string>' requires string as left operand, not {0}"
-        if isinstance(key, newstr):
+        # Don't use isinstance() here because we only want to catch
+        # newstr, not Python 2 unicode:
+        if type(key) == newstr:
             newkey = key
-        elif isinstance(key, unicode):
+        elif isinstance(key, unicode) or isinstance(key, bytes) and not isnewbytes(key):
             newkey = newstr(key)
         else:
             raise TypeError(errmsg.format(type(key)))
         return issubset(list(newkey), list(self))
     
-    @no(bytes)
+    @no('newbytes')
     def __add__(self, other):
         return newstr(super(newstr, self).__add__(other))
 
-    @no(bytes)
+    @no('newbytes')
     def __radd__(self, left):
         " left + self "
-        if isinstance(left, unicode):
-            try:
-                return newstr(left) + self
-            except:
-                raise NotImplemented
+        try:
+            return newstr(left) + self
+        except:
+            return NotImplemented
 
     def __mul__(self, other):
         return newstr(super(newstr, self).__mul__(other))
@@ -134,19 +143,22 @@ class newstr(unicode):
     def join(self, iterable):
         errmsg = 'sequence item {0}: expected unicode string, found bytes'
         for i, item in enumerate(iterable):
-            if isinstance(item, bytes):
+            # Here we use type() rather than isinstance() because
+            # __instancecheck__ is being overridden. E.g.
+            # isinstance(b'abc', newbytes) is True on Py2.
+            if isnewbytes(item):
                 raise TypeError(errmsg.format(i))
         return newstr(super(newstr, self).join(iterable))
 
-    @no(bytes)
+    @no('newbytes')
     def find(self, sub, *args):
         return super(newstr, self).find(sub, *args)
 
-    @no(bytes)
+    @no('newbytes')
     def rfind(self, sub, *args):
         return super(newstr, self).rfind(sub, *args)
 
-    @no(bytes, (1, 2))
+    @no('newbytes', (1, 2))
     def replace(self, old, new, *args):
         return newstr(super(newstr, self).replace(old, new, *args))
 
@@ -164,54 +176,56 @@ class newstr(unicode):
         'xmlcharrefreplace' as well as any other name registered with
         codecs.register_error that can handle UnicodeEncodeErrors.
         """
+        from future.builtins.backports.newbytes import newbytes
         # Py2 unicode.encode() takes encoding and errors as optional parameter,
         # not keyword arguments as in Python 3 str.
         return newbytes(super(newstr, self).encode(encoding, errors))
 
-    @no(bytes, 1)
+    @no('newbytes', 1)
     def startswith(self, prefix, *args):
         if isinstance(prefix, Iterable):
             for thing in prefix:
-                if not isinstance(thing, unicode):
+                if isnewbytes(thing):
                     raise TypeError(self.no_convert_msg.format(type(thing)))
         return super(newstr, self).startswith(prefix, *args)
 
-    @no(bytes, 1)
+    @no('newbytes', 1)
     def endswith(self, prefix, *args):
+        # Note we need the decorator above as well as the isnewbytes()
+        # check because prefix can be either a bytes object or e.g. a
+        # tuple of possible prefixes. (If it's a bytes object, each item
+        # in it is an int.)
         if isinstance(prefix, Iterable):
             for thing in prefix:
-                if not isinstance(thing, unicode):
+                if isnewbytes(thing):
                     raise TypeError(self.no_convert_msg.format(type(thing)))
         return super(newstr, self).endswith(prefix, *args)
 
+    @no('newbytes', 1)
     def split(self, sep=None, maxsplit=-1):
         # Py2 unicode.split() takes maxsplit as an optional parameter,
         # not as a keyword argument as in Python 3 str.
-        if sep is not None and not isinstance(sep, unicode):
-            raise TypeError(self.no_convert_msg.format(type(sep)))
         parts = super(newstr, self).split(sep, maxsplit)
         return [newstr(part) for part in parts]
 
-    @no(bytes, 1)
+    @no('newbytes', 1)
     def rsplit(self, sep=None, maxsplit=-1):
         # Py2 unicode.rsplit() takes maxsplit as an optional parameter,
         # not as a keyword argument as in Python 3 str.
-        if sep is not None and not isinstance(sep, unicode):
-            raise TypeError(self.no_convert_msg.format(type(sep)))
         parts = super(newstr, self).rsplit(sep, maxsplit)
         return [newstr(part) for part in parts]
 
-    @no(bytes, 1)
+    @no('newbytes', 1)
     def partition(self, sep):
         parts = super(newstr, self).partition(sep)
         return tuple(newstr(part) for part in parts)
 
-    @no(bytes, 1)
+    @no('newbytes', 1)
     def rpartition(self, sep):
         parts = super(newstr, self).rpartition(sep)
         return tuple(newstr(part) for part in parts)
 
-    @no(bytes, 1)
+    @no('newbytes', 1)
     def index(self, sub, *args):
         """
         Like newstr.find() but raise ValueError when the substring is not
@@ -223,13 +237,15 @@ class newstr(unicode):
         return pos
 
     def __eq__(self, other):
-        if isinstance(other, unicode):
+        if (isinstance(other, unicode) or
+            isinstance(other, bytes) and not isnewbytes(other)):
             return super(newstr, self).__eq__(other)
         else:
             return False
 
     def __ne__(self, other):
-        if isinstance(other, unicode):
+        if (isinstance(other, unicode) or
+            isinstance(other, bytes) and not isnewbytes(other)):
             return super(newstr, self).__ne__(other)
         else:
             return True
@@ -239,22 +255,22 @@ class newstr(unicode):
     def __lt__(self, other):
         if not istext(other):
             raise TypeError(self.unorderable_err.format(type(other)))
-        return super(newbytes, self).__lt__(other)
+        return super(newstr, self).__lt__(other)
 
     def __le__(self, other):
         if not istext(other):
             raise TypeError(self.unorderable_err.format(type(other)))
-        return super(newbytes, self).__le__(other)
+        return super(newstr, self).__le__(other)
 
     def __gt__(self, other):
         if not istext(other):
             raise TypeError(self.unorderable_err.format(type(other)))
-        return super(newbytes, self).__gt__(other)
+        return super(newstr, self).__gt__(other)
 
     def __ge__(self, other):
         if not istext(other):
             raise TypeError(self.unorderable_err.format(type(other)))
-        return super(newbytes, self).__ge__(other)
+        return super(newstr, self).__ge__(other)
 
     def __native__(self):
         return unicode(self)
