@@ -8,6 +8,8 @@ from future.builtins import *
 from future import utils
 from future.tests.base import unittest
 
+import os
+
 TEST_UNICODE_STR = u'ℝεα∂@ßʟ℮ ☂ℯṧт υηḯ¢☺ḓ℮'
 
 
@@ -17,6 +19,13 @@ class TestStr(unittest.TestCase):
         self.assertEqual(str('blah'), u'blah')  # u'' prefix: Py3.3 and Py2 only
         self.assertEqual(str(b'1234'), "b'1234'")
 
+    def test_os_path_join(self):
+        """
+        Issue #15: can't os.path.join(u'abc', str(u'def'))
+        """
+        self.assertEqual(os.path.join(u'abc', str(u'def')),
+                         u'abc{0}def'.format(os.sep))
+
     def test_str_encode_utf8(self):
         b = str(TEST_UNICODE_STR).encode('utf-8')
         self.assertTrue(isinstance(b, bytes))
@@ -25,6 +34,15 @@ class TestStr(unittest.TestCase):
         self.assertTrue(isinstance(s, str))
         self.assertEqual(s, TEST_UNICODE_STR)
 
+    def test_str_encode_cp1251(self):
+        b1 = b'\xcd\xeb\xff'
+        s1 = str(b1, 'cp1251')
+        self.assertEqual(s1, u'Нля')
+
+        b2 = bytes(b'\xcd\xeb\xff')
+        s2 = str(b2, 'cp1251')
+        self.assertEqual(s2, u'Нля')
+
     def test_str_encode_decode_with_py2_str_arg(self):
         # Try passing a standard Py2 string (as if unicode_literals weren't imported)
         b = str(TEST_UNICODE_STR).encode(utils.bytes_to_native_str(b'utf-8'))
@@ -105,8 +123,9 @@ class TestStr(unittest.TestCase):
     def test_str_plus_bytes(self):
         s = str(u'ABCD')
         b = b'EFGH'
-        with self.assertRaises(TypeError):
-            s + b
+        # We allow this now:
+        # with self.assertRaises(TypeError):
+        #     s + b
         # str objects don't have an __radd__ method, so the following
         # does not raise a TypeError. Is this a problem?
         # with self.assertRaises(TypeError):
@@ -131,9 +150,7 @@ class TestStr(unittest.TestCase):
 
         s4 = 'ZYXW' + s1
         self.assertEqual(s4, 'ZYXWABCD')
-        # str objects don't have an __radd__ method, so the following is
-        # not True. Is this a problem?
-        # self.assertTrue(isinstance(s4, str))
+        self.assertTrue(isinstance(s4, str))
 
     def test_str_join_str(self):
         s = str(' * ')
@@ -144,9 +161,12 @@ class TestStr(unittest.TestCase):
 
     def test_str_join_bytes(self):
         s = str('ABCD')
-        byte_strings = [b'EFGH', u'IJKL']
+        byte_strings1 = [b'EFGH', u'IJKL']
+        self.assertEqual(s.join(byte_strings1), u'EFGHABCDIJKL')
+
+        byte_strings2 = [bytes(b'EFGH'), u'IJKL']
         with self.assertRaises(TypeError):
-            s.join(byte_strings)
+            s.join(byte_strings2)
 
     def test_str_replace(self):
         s = str('ABCD')
@@ -155,9 +175,9 @@ class TestStr(unittest.TestCase):
         self.assertTrue(isinstance(c, str))
 
         with self.assertRaises(TypeError):
-            s.replace(b'A', u'F')
+            s.replace(bytes(b'A'), u'F')
         with self.assertRaises(TypeError):
-            s.replace(u'A', b'F')
+            s.replace(u'A', bytes(b'F'))
 
     def test_str_partition(self):
         s1 = str('ABCD')
@@ -178,8 +198,10 @@ class TestStr(unittest.TestCase):
     def test_str_contains_something(self):
         s = str('ABCD')
         self.assertTrue('A' in s)
+        if utils.PY2:
+            self.assertTrue(b'A' in s)
         with self.assertRaises(TypeError):
-            b'A' in s                  
+            bytes(b'A') in s                  
         with self.assertRaises(TypeError):
             65 in s                                 # unlike bytes
 
@@ -194,43 +216,62 @@ class TestStr(unittest.TestCase):
         with self.assertRaises(TypeError):
             s.index(67)
         with self.assertRaises(TypeError):
-            s.index(b'C')
+            s.index(bytes(b'C'))
 
     def test_startswith(self):
         s = str('abcd')
         self.assertTrue(s.startswith('a'))
         self.assertTrue(s.startswith(('a', 'd')))
         self.assertTrue(s.startswith(str('ab')))
+        if utils.PY2:
+            # We allow this, because e.g. Python 2 os.path.join concatenates
+            # its arg with a byte-string '/' indiscriminately.
+            self.assertFalse(s.startswith(b'A'))
+            self.assertTrue(s.startswith(b'a'))
         with self.assertRaises(TypeError) as cm:
-            s.startswith(b'A')
+            self.assertFalse(s.startswith(bytes(b'A')))
         with self.assertRaises(TypeError) as cm:
-            s.startswith((b'A', b'B'))
+            s.startswith((bytes(b'A'), bytes(b'B')))
         with self.assertRaises(TypeError) as cm:
             s.startswith(65)
 
+    def test_join(self):
+        sep = str('-')
+        self.assertEqual(sep.join('abcd'), 'a-b-c-d')
+        if utils.PY2:
+            sep.join(b'abcd')
+        with self.assertRaises(TypeError) as cm:
+            sep.join(bytes(b'abcd'))
+
     def test_endswith(self):
         s = str('abcd')
         self.assertTrue(s.endswith('d'))
         self.assertTrue(s.endswith(('b', 'd')))
         self.assertTrue(s.endswith(str('cd')))
         self.assertFalse(s.endswith(('A', 'B')))
-
+        if utils.PY2:
+            self.assertFalse(s.endswith(b'D'))
+            self.assertTrue(s.endswith((b'D', b'd')))
         with self.assertRaises(TypeError) as cm:
             s.endswith(65)
         with self.assertRaises(TypeError) as cm:
-            s.endswith([b'D'])
+            s.endswith((bytes(b'D'),))
 
     def test_split(self):
         s = str('ABCD')
         self.assertEqual(s.split('B'), ['A', 'CD'])
+        if utils.PY2:
+            self.assertEqual(s.split(b'B'), ['A', 'CD'])
         with self.assertRaises(TypeError) as cm:
-            s.split(b'B')
+            s.split(bytes(b'B'))
 
     def test_rsplit(self):
         s = str('ABCD')
         self.assertEqual(s.rsplit('B'), ['A', 'CD'])
+        if utils.PY2:
+            self.assertEqual(s.rsplit(b'B'), ['A', 'CD'])
         with self.assertRaises(TypeError) as cm:
-            s.rsplit(b'B')
+            s.rsplit(bytes(b'B'))
 
     def test_eq_bytes(self):
         s = str('ABCD')
@@ -238,12 +279,20 @@ class TestStr(unittest.TestCase):
         self.assertNotEqual(s, b)
         self.assertNotEqual(str(''), bytes(b''))
         native_s = 'ABCD'
-        self.assertNotEqual(b, native_s)
-        # Fails:
-        # self.assertNotEqual(native_s, b)
         native_b = b'ABCD'
-        self.assertNotEqual(native_b, s)
-        self.assertNotEqual(s, native_b)
+        self.assertFalse(b == native_s)
+        self.assertTrue(b != native_s)
+
+        # Fails on Py2:
+        # self.assertNotEqual(native_s, b)
+        # with no obvious way to change this.
+
+        # For backward compatibility with broken string-handling code in
+        # Py2 libraries, we allow the following:
+
+        if utils.PY2:
+            self.assertTrue(native_b == s)
+            self.assertFalse(s != native_b)
 
     def test_eq(self):
         s = str('ABCD')
@@ -251,7 +300,10 @@ class TestStr(unittest.TestCase):
         self.assertEqual(s, 'ABCD')
         self.assertEqual(s, s)
         self.assertTrue(u'ABCD' == s)
-        self.assertFalse(b'ABCD' == s)
+        if utils.PY2:
+            self.assertTrue(b'ABCD' == s)
+        else:
+            self.assertFalse(b'ABCD' == s)
         self.assertFalse(bytes(b'ABCD') == s)
 
     def test_ne(self):
@@ -261,7 +313,10 @@ class TestStr(unittest.TestCase):
         self.assertNotEqual(s, 5)
         self.assertNotEqual(2.7, s)
         self.assertNotEqual(s, ['A', 'B', 'C', 'D'])
-        self.assertTrue(b'ABCD' != s)
+        if utils.PY2:
+            self.assertFalse(b'ABCD' != s)
+        else:
+            self.assertTrue(b'ABCD' != s)
         self.assertTrue(bytes(b'ABCD') != s)
 
     def test_cmp(self):
